@@ -1,15 +1,15 @@
 from beanie import init_beanie
 from pymongo import AsyncMongoClient
 
-from .config import settings
-from .models.registry import get_all_models
+from vibetuner.config import settings
+from vibetuner.models.registry import get_all_models
 
 
 async def init_models() -> None:
     """Initialize MongoDB connection and register all Beanie models."""
 
     client: AsyncMongoClient = AsyncMongoClient(
-        host=str(settings.project.mongodb_url),
+        host=str(settings.mongodb_url),
         compressors=["zstd"],
     )
 
